@@ -11,8 +11,8 @@
 #include <sys/time.h>
 #include <arpa/inet.h>
 #include <sched.h>
-
-#include "asm/types.h"
+#include <time.h>
+#include <fcntl.h>
 
 struct cap_header {
 	u32 version;
