@@ -2,9 +2,10 @@
 #include <stdbool.h>
 #include <sys/mman.h>
 
+#include "page.h"
 #include "rst-malloc.h"
-#include "bug.h"
-#include "asm/types.h"
+#include "log.h"
+#include "common/bug.h"
 
 struct rst_mem_type_s {
 	bool remapable;
@@ -214,7 +215,7 @@ static int rst_mem_remap_one(struct rst_mem_type_s *t, void *to)
 
 	if (!t->buf)
 		/*
-		 * No allocations happenned from this buffer.
+		 * No allocations happened from this buffer.
 		 * It's safe just to do nothing.
 		 */
 		return 0;
