@@ -32,13 +32,13 @@ enum criu_service_comm {
 };
 
 enum criu_cg_mode {
-	CRIU_CG_MODE_IGNORE	= 0,
-	CRIU_CG_MODE_NONE	= 1,
-	CRIU_CG_MODE_PROPS	= 2,
-	CRIU_CG_MODE_SOFT	= 3,
-	CRIU_CG_MODE_FULL	= 4,
-	CRIU_CG_MODE_STRICT	= 5,
-	CRIU_CG_MODE_DEFAULT	= 6
+	CRIU_CG_MODE_IGNORE,
+	CRIU_CG_MODE_NONE,
+	CRIU_CG_MODE_PROPS,
+	CRIU_CG_MODE_SOFT,
+	CRIU_CG_MODE_FULL,
+	CRIU_CG_MODE_STRICT,
+	CRIU_CG_MODE_DEFAULT,
 };
 
 void criu_set_service_address(char *path);
@@ -92,6 +92,8 @@ int criu_add_enable_fs(char *fs);
 int criu_add_skip_mnt(char *mnt);
 void criu_set_ghost_limit(unsigned int limit);
 int criu_add_irmap_path(char *path);
+int criu_add_inherit_fd(int fd, char *key);
+int criu_add_external(char *key);
 
 /*
  * The criu_notify_arg_t na argument is an opaque
@@ -200,6 +202,8 @@ int criu_local_add_irmap_path(criu_opts *opts, char *path);
 int criu_local_add_cg_props(criu_opts *opts, char *stream);
 int criu_local_add_cg_props_file(criu_opts *opts, char *path);
 int criu_local_add_cg_dump_controller(criu_opts *opts, char *name);
+int criu_local_add_inherit_fd(criu_opts *opts, int fd, char *key);
+int criu_local_add_external(criu_opts *opts, char *key);
 
 void criu_local_set_notify_cb(criu_opts *opts, int (*cb)(char *action, criu_notify_arg_t na));
 
